@@ -19,10 +19,10 @@
 #define VOICESETUPDLG_H
 
 // QT includes
-#include <qframe.h>
+#include <Qt3Support/Q3Frame>
 
 // KDE includes
-#include <kdialogbase.h>
+#include <kpagedialog.h>
 #include <kconfig.h>
 
 // forward declaration
@@ -31,20 +31,20 @@ class KTTSDLib;
 /**
   *@author Robert Vogl
   */
-class VoiceSetupDlg : public KDialogBase  {
+class VoiceSetupDlg : public KPageDialog  {
   Q_OBJECT
 
 public: 
   VoiceSetupDlg(QWidget *parent=0, const char *name=0, const QString &caption=NULL,
         bool modal=true,
         KConfig *config=0,
-        FXPluginHandler *fxpluginhandler=0,
+        /*FXPluginHandler *fxpluginhandler=0,*/
         KTTSDLib *kttslib=0);
                   
   ~VoiceSetupDlg();
   
 signals:
-    /** Emitted when OK was cliecked;
+    /** Emitted when OK was clicked;
      */
     void signalOKWasClicked();
     
@@ -64,7 +64,7 @@ private: // Methods
     
     /** Initializes the configuration page to setup the effects.
      */
-    void initFXPage();
+    // void initFXPage();
     
 private slots:
     /** Called when the Page changes.
@@ -81,7 +81,7 @@ private slots:
        
 private:
     KConfig *m_config;
-    FXPluginHandler *m_fxpluginhandler;
+    // FXPluginHandler *m_fxpluginhandler;
     KTTSDLib *m_kttslib;
     QFrame *m_fxPage;
     
